@@ -14,7 +14,7 @@ import dateutil
 
 from django import forms
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .manager import dcolumn_manager
 from .models import CollectionBase, DynamicColumn, ColumnCollection, KeyValue
