@@ -17,7 +17,7 @@ from collections import OrderedDict
 from django.db import models
 from django.utils.html import format_html, format_html_join
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.core.exceptions import ValidationError
 
 from dcolumn.common import create_field_name
